@@ -3,7 +3,7 @@
 
 import requests
 import json
-
+import re
 
 class HTTPRequestNotifier(object):  # pylint: disable=unused-variable
     """Trigger an HTTP request with backwork-notifier-http"""
@@ -78,13 +78,9 @@ class HTTPRequestNotifier(object):  # pylint: disable=unused-variable
             paths = key.split(".")
             length = len(paths)
             if length == 6:
-                data[paths[0]][paths[1]][paths[2]][paths[3]][paths[4]][
-                    paths[5]
-                ] = "{}".format(msg)
+                data[paths[0]][paths[1]][paths[2]][paths[3]][paths[4]][paths[5]] = "{}".format(msg)
             elif length == 5:
-                data[paths[0]][paths[1]][paths[2]][paths[3]][paths[4]] = "{}".format(
-                    msg
-                )
+                data[paths[0]][paths[1]][paths[2]][paths[3]][paths[4]] = "{}".format(msg)
             elif length == 4:
                 data[paths[0]][paths[1]][paths[2]][paths[3]] = "{}".format(msg)
             elif length == 3:
@@ -105,6 +101,27 @@ class HTTPRequestNotifier(object):  # pylint: disable=unused-variable
     def formatJson(self, data):
         return str(data).strip("'<>() ").replace("'", '"')
 
+    def redaction(self, msg):
+        REDACTED = '[REDACTED]'
+
+        try:
+            msg = str(msg)
+            credentials = re.search('(?<=:\/\/).*(?=@)', msg)
+            if credentials:
+                credentials = credentials.group().split(':')
+                msg = msg.replace(credentials[0], REDACTED)
+                msg = msg.replace(credentials[1], REDACTED)
+            else: 
+                credentials = re.findall("(?<=\s)'\w+'", msg)
+                if credentials: 
+                    msg = msg.replace(credentials[0], REDACTED)
+                    msg = msg.replace(credentials[1], REDACTED)
+
+        except Exception as e:
+            self.log("Unable to redact credentials... Error: {}".format(str(e)))
+
+        return msg
+
     def notify(self, msg=""):
         """Notify an HTTP endpoint."""
 
@@ -159,6 +176,9 @@ class HTTPRequestNotifier(object):  # pylint: disable=unused-variable
                     )
                 )
 
+        # redact service credentials.
+        msg = self.redaction(msg)
+
         # attach msg to data object to be sent
         data = self.addKeyToObject(key, msg, data)
 
